# ------------------------------------------------------------
# check_dir_path()
# ------------------------------------------------------------

check_dir_path() {

BUILDPATH=`echo $1 | sed -e 's/\// /g'`

[ X"$BUILDPATH" = X ] && doerror "check_dir_path(): pathname expected"

TMPPATH=`pwd`

cd /

for i in $BUILDPATH; do
#    BUILDPATH="$BUILDPATH"/$i
    if [ ! -d $i ]; then
	mkdir $i || doerror can\'t create `pwd`/$i!
        chown root:0 $i && chmod 775 $i
        [ $? = 0 ] || doerror failed to set permissions for `pwd`/$i
	$doecho created `pwd`/$i
	sleep 1
    fi
    cd $i
done

cd $TMPPATH
}

# ------------------------------------------------------------
# check_ups_dir()
# ------------------------------------------------------------

check_ups_dir() {

UPS_PARENT=`echo $UPS_DIR | sed -e 's/\/[^\/]*$//'`
dodebug "UPS_PARENT = >$UPS_PARENT<"

[ -d $UPS_PARENT ] \
|| doerror can\'t find $UPS_PARENT, no such directory, please create manually!

[ -d $UPS_DIR ] || mkdir $UPS_DIR || doerror can\'t create $UPS_DIR!

chown root:0 $UPS_DIR && chmod 775 $UPS_DIR
[ $? = 0 ] || doerror failed to fix permissions for $UPS_DIR

}

# ------------------------------------------------------------
# find_initdir()
# ------------------------------------------------------------

find_initdir() {
if [ -d /etc/init.d ]; then
    initdir=/etc/init.d
elif [ -d /etc/rc.d/init.d ]; then
    initdir=/etc/rc.d/init.d
elif [ -d /sbin/init.d ]; then
    initdir=/sbin/init.d
elif [ -d /sbin/rc.d/init.d ]; then
    initdir=/sbin/rc.d/init.d
else
    initdir=""
    return 1
fi

}

# ------------------------------------------------------------
# find_rcparent()
# ------------------------------------------------------------

find_rcparent() {

if [ -d /etc/rc2.d ]; then
    rc_parent=/etc
elif [ -d /etc/init.d/rc2.d ]; then
    rc_parent=/etc/init.d
elif [ -d /etc/rc.d/rc2.d ]; then
    rc_parent=/etc/rc.d
elif [ -d /sbin/init.d/rc2.d ]; then
    rc_parent=/sbin/init.d
elif [ -d /sbin/rc2.d ]; then # HP-UX
    rc_parent=/sbin
else
    rc_parent=""
    return 1
fi

}

# ------------------------------------------------------------
# WriteShutdownCommand()
# ------------------------------------------------------------

WriteShutdownCommand() {

[ -z "$SHUTDOWNCOM" ] && SHUTDOWNCOM=doshutdown.sh
[ -z "$sysdownprog" ] && doerror \"sysdownprog\" undefined!

if [ -f $SHUTDOWNCOM ]; then
    $doecho \\nsave existing `pwd`/$SHUTDOWNCOM to `pwd`/${SHUTDOWNCOM}.bkp... \\c
    mv $SHUTDOWNCOM ${SHUTDOWNCOM}.bkp || doerror failed to rename $SHUTDOWNCOM
    $doecho ok!; sleep 1
fi

$doecho \\nWriting default command file `pwd`/${SHUTDOWNCOM}... \\c

cat > ${SHUTDOWNCOM}<<EOF
#!/bin/sh
# This script is called by upsman|rccmd and initiates system shutdown
#

cd /
sync ; sync ; sync
$sysdownprog &
exit 0
EOF

[ $? = 0 ] && chown root:0 $SHUTDOWNCOM && chmod 774 $SHUTDOWNCOM
[ $? = 0 ] || doerror failed to write $SHUTDOWNCOM!

$doecho ok!; sleep 1
}

# ------------------------------------------------------------
# WriteMessageCommand()
# ------------------------------------------------------------

WriteMessageCommand() {

[ -z "$MESSAGECOM" ] && MESSAGECOM=message.sh
[ -z "$sysdownprog" ] && doerror \"sysdownprog\" undefined!

if [ -f $MESSAGECOM ]; then
    $doecho \\nsave existing `pwd`/$MESSAGECOM to `pwd`/${MESSAGECOM}.bkp... \\c
    mv $MESSAGECOM ${MESSAGECOM}.bkp || doerror failed to rename $MESSAGECOM
    $doecho ok!; sleep 1
fi

$doecho \\nWriting default command file `pwd`/${MESSAGECOM}... \\c

cat > $MESSAGECOM<<EOF
#!/bin/sh 

# This script is called by upsman when executing the functions
# "Send Messagebox with Text" and "Send default message IDs from file
# messages.dat" in the event-configuration.
#
#$UPSIDENT

# available parameters are:
# \$1 = "TEXT", message to send
# \$2 = "ADDRESS", recipient of message

send_popup(){
if [ x\$DISPLAY != x -a -x ./upspopup ]; then
    ./upspopup -display \$DISPLAY \$1
fi
}

# check input

if [ -n "\$2" -a "\$2" != "local" -a "\$2" != "*" ]; then
write \$2 <<-!
    \$1
!
else
wall <<-!
    \$1
!
# uncomment the following line if you like to send the popup
# (be sure you set \$DISPLAY right)
# send_popup \$1
fi
exit 0
EOF

[ $? = 0 ] && chown root:0 $MESSAGECOM && chmod 774 $MESSAGECOM
[ $? = 0 ] || doerror failed to write $MESSAGECOM!

$doecho ok!; sleep 1
}

# ------------------------------------------------------------
# WriteMailCommand()
# ------------------------------------------------------------

WriteMailCommand() {

[ -z "$MAILCOM" ] && MAILCOM=upssend.sh
[ -z "$sysdownprog" ] && doerror \"sysdownprog\" undefined!

if [ -f $MAILCOM ]; then
    $doecho \\nsave existing `pwd`/$MAILCOM to `pwd`/${MAILCOM}.bkp... \\c
    mv $MAILCOM ${MAILCOM}.bkp || doerror failed to rename $MAILCOM
    $doecho ok!; sleep 1
fi

$doecho \\nWriting default command file `pwd`/${MAILCOM}... \\c

cat > $MAILCOM<<EOF
#!/bin/sh

# This script is called by upsman when executing the function "send email"
# in the event-configuration.

# available parameters are:
# ./upssend.sh -s <subject> -r <recipient> <message>
# -s <subject>   - Email header Subject
# -r <recipient> - Recipient's Email address
# <message>      - Email body content

# check input
while [ \$# -gt 0 ]; do
        case \$1 in
                -s) U_SUBJECT=\$2; shift;;
                -r) U_RECIPIENT=\$2; shift;;
                *) break;;
        esac
        shift
done

U_MESSAGE=\$@

[ X"\$U_RECIPIENT" = X ] && U_RECIPIENT=postmaster
[ X"\$U_SUBJECT" = X ] && U_SUBJECT="UPS event"
[ X"\$U_MESSAGE" = X ] && U_MESSAGE="executing \"send mail\" on ups-event, no message configured"

# send it
echo \$U_MESSAGE | $mailprog -s "\$U_SUBJECT" \$U_RECIPIENT

exit
EOF

[ $? = 0 ] && chown root:0 $MAILCOM && chmod 774 $MAILCOM
[ $? = 0 ] || doerror failed to write $MAILCOM!

$doecho ok!; sleep 1
}

# ------------------------------------------------------------
# WriteAlarmCommand()
# ------------------------------------------------------------

WriteAlarmCommand() {

[ -z "$ALARMCOM" ] && ALARMCOM=alarm.sh
[ -z "$sysdownprog" ] && doerror \"sysdownprog\" undefined!

if [ -f $ALARMCOM ]; then
    #$doecho \\nsave existing `pwd`/$ALARMCOM to `pwd`/${ALARMCOM}.bkp... \\c
    #mv $ALARMCOM ${ALARMCOM}.bkp || doerror failed to rename $ALARMCOM
    #$doecho ok!; sleep 1
    rm $ALARMCOM || doerror failed to rename $ALARMCOM
fi

#$doecho \\nWriting default command file `pwd`/${ALARMCOM}... \\c

ln -s $MESSAGECOM $ALARMCOM  || doerror failed to link $ALARMCOM
}

# ------------------------------------------------------------
# check_java()
# ------------------------------------------------------------

check_java() {

$doecho \\ntesting for Java... \\c

#ISJAVA=`$progtestprog java 2>/dev/null`
#[ -z "$ISJAVA" ] && ISJAVA=`$progtestprog jre 2>/dev/null`
#ISJAVA=[ `$progtestprog java 2>/dev/null` ] || [ `$progtestprog jre 2>/dev/null` ]
if ($progtestprog java >/dev/null 2>&1) || ($progtestprog jre >/dev/null 2>&1); then
    $doecho ok!
else
    $doecho missing!\\nneither \"java\" nor \"jre\" is in your path. Please install Java Runtime Environment.
fi
sleep 1
}

# ------------------------------------------------------------
# check_for_abs_path()
# ------------------------------------------------------------

check_for_abs_path() {

[ X"$1" = X ] && return 1

[ X`echo "$1" | sed -e 's/^[^\/].*$//'` = X ] && return 1

return 0
}

# ------------------------------------------------------------
# check_for_prog()
# ------------------------------------------------------------

check_for_prog() {

#$doecho \\ntesting for Java... \\c
TMPPROG=$1
[ X"$TMPPROG" != X ] || return 1

TMPOUT=`$progtestprog $TMPPROG 2>/dev/null | sed -e 's/^[^\/]*//'`

[ X"$TMPOUT" != X  ]
}

# ------------------------------------------------------------
# do_messages_inst()
# ------------------------------------------------------------

do_messages_inst() {
if [ -d $VER/[Mm][Ee][Ss][Ss][Aa][Gg][Ee] ]; then
    MESSAGE=`ls -d $VER/[Mm][Ee][Ss][Ss][Aa][Gg][Ee]`
else
    doerror can\'t find $VER/MESSAGE, no such directory!
fi

if [ -f $MESSAGE/$D/[Ee][Nn][Gg][Ll][Ii][Ss][Hh]/[Mm][Ee][Ss][Ss][Aa][Gg][Ee][Ss].[Dd][Aa][Tt] ]; then
    LANGDIR=$MESSAGE/$D
elif [ -f $MESSAGE/1/[Ee][Nn][Gg][Ll][Ii][Ss][Hh]/[Mm][Ee][Ss][Ss][Aa][Gg][Ee][Ss].[Dd][Aa][Tt] ]; then
    LANGDIR=$MESSAGE/1
else
    doerror can\'t find messages database in $MESSAGE!
fi

# check if language allready choosen
if [ -n "$UPSLANG" -a -d $LANGDIR/$UPSLANG ]; then
    MESSAGES_DAT=`ls $LANGDIR/$UPSLANG/[Mm][Ee][Ss][Ss][Aa][Gg][Ee][Ss].[Dd][Aa][Tt] 2>/dev/null`
fi

# we need messages.dat
if [ ! -f "$MESSAGES_DAT" ]; then
    # ChooseLanguage reads $PRG, $LANGDIR sets $UPSLANG
    ChooseLanguage
    if [ -d $LANGDIR/$UPSLANG ]; then
        MESSAGE_LANG_DIR=$LANGDIR/$UPSLANG
    else
        doerror can\'t find $LANGDIR/$UPSLANG, no such directory!
    fi
    if [ -f $MESSAGE_LANG_DIR/[Mm][Ee][Ss][Ss][Aa][Gg][Ee][Ss].[Dd][Aa][Tt] ]; then
        MESSAGES_DAT=`ls $MESSAGE_LANG_DIR/[Mm][Ee][Ss][Ss][Aa][Gg][Ee][Ss].[Dd][Aa][Tt] 2>/dev/null`
    else
        doerror can\'t find $MESSAGE_LANG_DIR/messages.dat, no such file!
    fi
fi

$doecho \\nInstall messages database to `pwd`/messages.dat... \\c

cp $MESSAGES_DAT ./messages.dat || doerror failed to copy $MESSAGES_DAT

chown root:0 messages.dat && chmod 664 messages.dat
[ $? = 0 ] || doerror failed to fix permissions for `pwd`/messages.dat

$doecho ok!; sleep 1
}

